GisPy
=====

GisPy is a python package of basic GIS operations for use on GDAL raster datasets and OGR
vector data sources. I developed this package for personal use and not for widespread
distribution.

Depedencies
-----------

- gdal
- numpy
- scipy
